Learn R Programming

sitreeE (version 0.0-10)

PBAL.dbh.greater: Basal area of larger trees which are at least X cm larger than the tree of interest

Description

Calculates the basal area (in cm2 if dbh is in mm) of trees that are at least X (in the same units as dbh) larger than the tree of interest for a list of trees.

Usage

PBAL.dbh.greater(dbh.mm, dbh.mm.diff)

Value

It returns a list with the basal area of larger trees.

Arguments

dbh.mm

a vector of dbh in mm

dbh.mm.diff

minimum dbh difference between the tree and the tree of interest to be considered

Author

Cara Antón-Fernández (email: caf@nibio.no)

Details

It estimates the basal area (in cm2) of trees that are at least dbh.mm.diff mm larger than the tree of interest.

See Also

PBAL

Examples

Run this code
library(sitree)
PBAL.dbh.greater(c(100,89,51,74,4), 3)

aggregate(dbh ~ plot.id, data = tr, FUN = PBAL.dbh.greater, dbh.mm.diff = 2)

Run the code above in your browser using DataLab