Learn R Programming

sitreeE (version 0.0-10)

biomass.norway.sitree: Calculates biomass for trees using the Norwegian biomass equations

Description

Calculates biomass for trees using the Norwegian biomass equations.

Usage

biomass.norway.sitree(dbh.mm, height.dm, tree.sp)

Value

Returns a data.table containing the 12 columns resulting from applying the biomass functions.

Arguments

dbh.mm

Diameter at breast height in mm.

height.dm

Tree height in dm.

tree.sp

Tree species according to the Norwegian NFI. It will use biomass.spruce.M1988 when tree.sp is 1, 2, 3, 21, or 29, biomass.pine.M1988 when tree.sp is 10, 11, or 20, and biomass.birch.S2014 otherwise.

See Also

biomass.birch.S2014, biomass.pine.M1988, biomass.spruce.M1988

Examples

Run this code
bio.nor <- biomass.norway.sitree (dbh.mm = c(50, 60, 100 ), height.dm = c(40, 60,
                                 80),
                       tree.sp = c(1, 10, 30))
				

Run the code above in your browser using DataLab