powered by
It calculates the mean height of the X tallest trees by grouping variable (e.g. the plot ID)
height.of.X.tallest.trees(height, uplotID, num.trees)
It returns a data.frame with two columns containing the uplotID and the mean height of the X tallest trees.
A vector with heights
A vector with the grouping variable, most often this would be the plot ID.
Number of trees used to calculate the mean height.
Clara Antón Fernández (caf@nibio.no)
lorey.height
library(sitree) height.of.X.tallest.trees(height = tr$height, uplotID = tr$plot.id, 5)
Run the code above in your browser using DataLab