It returns a data.frame with two columns: top.heights in the same units as height, and plot.id.
Arguments
thickness
A vector with the thickness for every tree. Other variables can be used instead to thickness. This is only used to order the trees.
height
Height of the trees.
num.trees.per.ha
Number of trees per ha that the top height should correspond to. E.g. 100 trees per ha.
plot.id
Vector with the plot.id to which every tree corresponds to.
plot.size.m2
Plot size in square meters. It can be either a single number if all plots have the same size of a vector of equal length as thickness, height, and plot.id with the corresponding plot size for each tree.
Details
thickness, height, and plot.id should have the same length, that is, one value per tree.