Learn R Programming

sitreeE (version 0.0-10)

volume.sitree: Volume for sitree output for Norwegian conditions

Description

It calculates volume following the Norwegian national forest inventory equations for a trList or trListDead object

Usage

volume.sitree(tr, plot.data)

Value

It returns a data.table with columns for treeid, plot.id, dbh.mm, height.dm, kom, tree2ha, tree.sp, vol.w.tr.m3 (volume with bark in m3 per tree), and vol.wo.tr.m3 (volume without bark in m3 per tree)

Arguments

tr

a trListDead or trList object

plot.data

a list or data.frame containing at least a 'kom' and 'tree2ha' column/element. kom is the kommune (municipality) code, and tree2ha should be the expansion factor to go from tree to per ha basis.

Author

Clara Antón-Fernández (email: caf@nibio.no)

Details

It uses the volume.norway function to estimate the volume for all trees with dbh.mm greater than 0. It returns NA when dbh.mm is 0 or lower. tree2ha is included to facilitate the calculation of per ha values.

Examples

Run this code
library(sitree)
res <- sitree (tree.df   = tr,
               stand.df  = fl,
               functions = list(
                 fn.growth     = 'grow.dbhinc.hgtinc',
                 fn.mort       = 'mort.B2007',
                 fn.recr       = 'recr.BBG2008',
                 fn.management = 'management.prob',
                 fn.tree.removal = 'mng.tree.removal',
                 fn.modif      = NULL, 
                 fn.prep.common.vars = 'prep.common.vars.fun'
               ),
               n.periods = 5,
               period.length = 5,
               mng.options = NA,
               print.comments = FALSE,
               fn.dbh.inc = "dbhi.BN2009",
               fn.hgt.inc =  "height.korf", 
               species.spruce = c(1, 2, 3),
               species.pine = c(10, 11, 20, 21, 29),
               species.harw = c(30, 31),
               fun.final.felling = "harv.prob",
               fun.thinning      = "thin.prob",
                  per.vol.harv = 0.83
               )
volume.sitree(tr = res$live, plot.data = res$plot.data)

Run the code above in your browser using DataLab